@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Bucket;
-$Net::Amazon::S3::Bucket::VERSION = '0.92';
+$Net::Amazon::S3::Bucket::VERSION = '0.93';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Carp;
@@ -179,7 +179,7 @@ sub delete_multi_object {
             'Net::Amazon::S3::Operation::Objects::Delete',
 
             keys    => [
-				map { ref ? $_->key : $_ }
+				map { ref ($_) ? $_->key : $_ }
 				splice @objects, 0, ((scalar(@objects) > 1000) ? 1000 : scalar(@objects))
 			]
         );
@@ -444,7 +444,7 @@ Net::Amazon::S3::Bucket - convenience object for working with Amazon S3 buckets
 
 =head1 VERSION
 
-version 0.92
+version 0.93
 
 =head1 SYNOPSIS
 
